@@ -61,7 +61,7 @@
 #' # Create a met file for Kingsthorpe, Qld
 #' # from 1985-01-01 to 1985-06-30 and
 #' # save it in the current R session
-#' # tempdir() as APSIM_example.met
+#' # tempdir() as `APSIM_example.met`
 #'
 #' \donttest{
 #' create_met(lonlat = c(151.81, -27.48),
@@ -79,7 +79,11 @@ create_met <- function(lonlat,
                        file_out) {
   file_out <- .met_checks(.dsn = dsn, .file_out = file_out)
 
-  power_data <- .get_met_data(.dates = dates, .lonlat = lonlat)
+  power_data <-
+    .get_met_data(.dates = dates,
+                  .dsn = dsn,
+                  .lonlat = lonlat,
+                  .file_out = file_out)
 
   APSIM::writeMetFile(fileName = file.path(dsn, file_out),
                       met = power_data)
@@ -118,7 +122,7 @@ create_met <- function(lonlat,
 #' the file and corresponding units
 #'
 #' @noRd
-.get_met_data <- function(.dates, .lonlat) {
+.get_met_data <- function(.dates, .lonlat, .dsn, .file_out) {
   power_data <- as.data.frame(
     get_power(
       pars = c("T2M_MAX",
@@ -132,6 +136,10 @@ create_met <- function(lonlat,
     )
   )
 
+  .check_met_missing(.power_data = power_data, #nocov start
+                     .dsn = .dsn,
+                     .file_out = .file_out) #nocov end
+
   power_data <-
     power_data[c("T2M_MAX",
                  "T2M_MIN",
@@ -167,3 +175,33 @@ create_met <- function(lonlat,
     )
   return(out)
 }
+
+#' Check for Missing Values in .met File
+#'
+#' Checks for missing values in .met file. If missing values are found, a
+#' message is emitted as well as an auxilary .csv file being written to disk
+#' alongside the .met file for the user to refer to
+#'
+#' @param .power_data data from a `get_power()` query
+#' @param .file_out user-supplied file name for .met file output
+#'
+#' @return A .csv file if missing values are found
+#'
+#' @noRd
+.check_met_missing <- function(.power_data, .dsn, .file_out) {
+  if (any(is.na(as.data.frame(.power_data)))) {
+    m <-
+      as.data.frame(which(is.na(as.data.frame(.power_data)), arr.ind = TRUE))
+    col_names <- names(.power_data)[unique(m[, 2])][match(m[, 2],
+                                                          c(unique(m[, 2])))]
+    m <- data.frame(col_names, m[, c(2, 1)])
+    message(
+      "\nThere are missing values in your .MET file, an auxillary file `",
+      tools::file_path_sans_ext(.file_out),
+      "_missing.csv` has been created as well.\n",
+      paste0(utils::capture.output(m), collapse = "\n")
+    )
+    readr::write_csv(x = m,
+                     path = file.path(.dsn, paste0(.file_out, "_missing.csv")))
+  }
+}
